XorStep

Enum XorStep 

pub enum XorStep {
    Conflict(Vec<Lit>),
    Imply {
        lit: Lit,
        reason: Vec<Lit>,
    },
    Sat,
}
The result of consulting the engine at a Boolean fixpoint.

Variants



Conflict(Vec<Lit>)

The linear system is violated under the current assignment; the clause is implied by the formula and fully falsified (a conflict).



Imply

lit is forced; the clause is implied and unit (its only unassigned literal is lit).

Fields

lit: Lit
reason: Vec<Lit>


Sat

No XOR-forced literal and no contradiction at this assignment.